@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 from tests import msg
-from uamobile import detect, Context
+from uamobile import *
 from uamobile.ezweb import EZwebUserAgent
 from uamobile.factory.ezweb import EZwebUserAgentFactory
 
+def test_detect_fast():
+    assert detect_fast('KDDI-HI36 UP.Browser/6.2.0.10.4 (GUI) MMP/2.0') == 'ezweb'
+
 def test_netfront_nonmobile_mode():
     ua = detect({'HTTP_USER_AGENT':'KDDI-TS3A UP.Browser/6.2.0.11.2.1 (GUI) MMP/2.0, Mozilla/4.08 (MobilePhone; NMCS/3.3) NetFront/3.3'})
     assert ua.is_ezweb()
